Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(319)

Unified Diff: Source/core/css/AffectedByFocusTest.cpp

Issue 1033943002: Rename LayoutStyle to papayawhip (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: ensureComputedStyle Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/core.gypi ('k') | Source/core/css/BasicShapeFunctions.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/css/AffectedByFocusTest.cpp
diff --git a/Source/core/css/AffectedByFocusTest.cpp b/Source/core/css/AffectedByFocusTest.cpp
index 9198abc4ea353f460b8d52bda73d7e49c410443a..e3bf990fe47d4cabe7505121ce2bb435ce499cb4 100644
--- a/Source/core/css/AffectedByFocusTest.cpp
+++ b/Source/core/css/AffectedByFocusTest.cpp
@@ -6,7 +6,7 @@
#include "core/HTMLNames.h"
#include "core/dom/Element.h"
#include "core/dom/ElementTraversal.h"
-#include "core/dom/NodeLayoutStyle.h"
+#include "core/dom/NodeComputedStyle.h"
#include "core/dom/StyleEngine.h"
#include "core/frame/FrameView.h"
#include "core/html/HTMLDocument.h"
@@ -63,8 +63,8 @@ void AffectedByFocusTest::checkElements(ElementResult expected[], unsigned expec
for (; element && i < expectedCount; element = Traversal<HTMLElement>::next(*element), ++i) {
ASSERT_TRUE(element->hasTagName(expected[i].tag));
- ASSERT(element->layoutStyle());
- ASSERT_EQ(expected[i].affectedBy, element->layoutStyle()->affectedByFocus());
+ ASSERT(element->computedStyle());
+ ASSERT_EQ(expected[i].affectedBy, element->computedStyle()->affectedByFocus());
ASSERT_EQ(expected[i].childrenOrSiblingsAffectedBy, element->childrenOrSiblingsAffectedByFocus());
}
@@ -73,7 +73,7 @@ void AffectedByFocusTest::checkElements(ElementResult expected[], unsigned expec
// A global :focus rule in html.css currently causes every single element to be
// affectedByFocus. Check that all elements in a document with no :focus rules
// gets the affectedByFocus set on LayoutStyle and not childrenOrSiblingsAffectedByFocus.
TEST_F(AffectedByFocusTest, UAUniversalFocusRule)
{
ElementResult expected[] = {
@@ -73,7 +73,7 @@ void AffectedByFocusTest::checkElements(ElementResult expected[], unsigned expec
// A global :focus rule in html.css currently causes every single element to be
// affectedByFocus. Check that all elements in a document with no :focus rules
-// gets the affectedByFocus set on LayoutStyle and not childrenOrSiblingsAffectedByFocus.
+// gets the affectedByFocus set on ComputedStyle and not childrenOrSiblingsAffectedByFocus.
TEST_F(AffectedByFocusTest, UAUniversalFocusRule)
{
« no previous file with comments | « Source/core/core.gypi ('k') | Source/core/css/BasicShapeFunctions.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698